
# Type: molecular activity_has output




URI: [biolink:molecular_activity_has_output](https://w3id.org/biolink/vocab/molecular_activity_has_output)


## Domain and Range

[MolecularActivity](MolecularActivity.md) ->  <sub>0..*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents

 *  is_a: [has output](has_output.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)
